==> haskell-mmap-0.5.9-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmap
version:              0.5.9
visibility:           public
id:                   mmap-0.5.9-dZ6MGN9EmRCBoYSdK9psL
key:                  mmap-0.5.9-dZ6MGN9EmRCBoYSdK9psL
license:              BSD-3-Clause
copyright:            2008-2012, Gracjan Polak
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Gracjan Polak <gracjanpolak@gmail.com>
stability:            stable
synopsis:             Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.

category:             System
abi:                  48510ea4dd507a0cb7b5d0b9b80ffbda
exposed:              True
exposed-modules:      System.IO.MMap
import-dirs:          /usr/lib/ghc-8.8.3/site-local/mmap-0.5.9
library-dirs:         /usr/lib/ghc-8.8.3/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/mmap-0.5.9
hs-libraries:         HSmmap-0.5.9-dZ6MGN9EmRCBoYSdK9psL
depends:              base-4.13.0.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html:         /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmap-0.5.9-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmap
version:              0.5.9
visibility:           public
id:                   mmap-0.5.9-1j4kriGUUr4GQUg5i4inMg
key:                  mmap-0.5.9-1j4kriGUUr4GQUg5i4inMg
license:              BSD-3-Clause
copyright:            2008-2012, Gracjan Polak
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Gracjan Polak <gracjanpolak@gmail.com>
stability:            stable
synopsis:             Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.

category:             System
abi:                  947ecfdb69a67e651c7563e8dc5b6a90
exposed:              True
exposed-modules:      System.IO.MMap
import-dirs:          /usr/lib/ghc-8.10.1/site-local/mmap-0.5.9
library-dirs:         /usr/lib/ghc-8.10.1/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/mmap-0.5.9
hs-libraries:         HSmmap-0.5.9-1j4kriGUUr4GQUg5i4inMg
depends:              base-4.14.0.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html:         /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
